/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Processes goog.tsMigrationExportsShim, goog.tsMigrationDefaultExportsShim,
 * and goog.tsMigrationNamedExportsShim statements into
 * ".legacy.closure.js" and ".legacy.d.ts" files.
 */
import * as ts from 'typescript';
import { ModulesManifest } from './modules_manifest';
/** Silence linter. */
export interface TsMigrationExportsShimResult {
    filename: string;
    content: string;
    diagnostics: ts.Diagnostic[];
}
/** Provides dependencies for file generation. */
export interface TsMigrationExportsShimProcessorHost {
    /** If true emit .legacy.closure.js file, else emit .legacy.d.ts */
    transformTypesToClosure?: boolean;
    /** See compiler_host.ts */
    pathToModuleName(context: string, importPath: string): string;
    /** See compiler_host.ts */
    rootDirsRelative(fileName: string): string;
}
/** Silence linter. */
export declare function generateTsMigrationExportsShimFile(src: ts.SourceFile, typeChecker: ts.TypeChecker, host: TsMigrationExportsShimProcessorHost, manifest: ModulesManifest): TsMigrationExportsShimResult;
/**
 * Does this path have a file extension that supports
 * calls to tsmes?
 */
export declare function pathHasSupportedExtension(p: string): boolean;
